/*
 * Copyright 2013 Tsukasa Kitachi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.kxbmap.ipchecker.example

import io.netty.bootstrap.Bootstrap
import io.netty.channel.nio.NioEventLoopGroup
import io.netty.channel.socket.nio.NioSocketChannel
import java.net.InetSocketAddress

object IPCheckerClient extends App {
  val address = args.toSeq match {
    case Seq(h, p)  => new InetSocketAddress(h, p.toInt)
    case Seq(p)     => new InetSocketAddress(p.toInt)
    case _          => throw new IllegalArgumentException()
  }

  val group = new NioEventLoopGroup()

  try new Bootstrap()
    .group(group)
    .channel(classOf[NioSocketChannel])
    .handler(new IPCheckerClientInitializer())
    .connect(address).sync()
    .channel()
    .closeFuture().sync()
  finally
    group.shutdownGracefully()
}
