/*
 * Copyright 2013 Tsukasa Kitachi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.kxbmap.ipchecker.example

import io.netty.channel.ChannelHandler.Sharable
import io.netty.channel.{ChannelHandlerContext, ChannelInboundMessageHandlerAdapter}
import io.netty.util.internal.logging.InternalLoggerFactory
import java.net.InetAddress

@Sharable
class IPCheckerClientHandler extends ChannelInboundMessageHandlerAdapter[InetAddress] {
  val logger = InternalLoggerFactory.getInstance(classOf[IPCheckerClientHandler])

  def messageReceived(ctx: ChannelHandlerContext, msg: InetAddress) {
    logger.info(s"Received: $msg")
  }

  override def exceptionCaught(ctx: ChannelHandlerContext, cause: Throwable) {
    logger.warn("Unexpected exception", cause)
    ctx.close()
  }
}
