/*
 * Copyright 2013 Tsukasa Kitachi
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.github.kxbmap.ipchecker.example

import io.netty.bootstrap.ServerBootstrap
import io.netty.channel.nio.NioEventLoopGroup
import io.netty.channel.socket.nio.NioServerSocketChannel
import io.netty.handler.logging.{LogLevel, LoggingHandler}
import java.net.InetSocketAddress

object IPCheckerServer extends App {
  val address = args.toSeq match {
    case Seq(h, p)  => new InetSocketAddress(h, p.toInt)
    case Seq(p)     => new InetSocketAddress(p.toInt)
    case _          => throw new IllegalArgumentException()
  }

  val boss    = new NioEventLoopGroup()
  val worker  = new NioEventLoopGroup()

  try new ServerBootstrap()
    .group(boss, worker)
    .channel(classOf[NioServerSocketChannel])
    .handler(new LoggingHandler(LogLevel.DEBUG))
    .childHandler(new IPCheckerServerInitializer())
    .bind(address).sync()
    .channel()
    .closeFuture().sync()
  finally {
    boss.shutdownGracefully()
    worker.shutdownGracefully()
  }

}
